@@ -23,9 +23,12 @@ package require user
 package require db
 package require module
 
-if ...
-source modules/autoload/onlyonce/siteconfig.tcl
-source local/modules/autoload/onlyonce/siteconfig.tcl
+if {[file exists modules/autoload/onlyonce/siteconfig.tcl]} {
+	source modules/autoload/onlyonce/siteconfig.tcl
+}
+if {[file exists local/modules/autoload/onlyonce/siteconfig.tcl]} {
+	source local/modules/autoload/onlyonce/siteconfig.tcl
+}
 
 if {[info exists config::db(unconfigured)]} {
 	puts -nonewline "DB Username: "
@@ -50,13 +53,14 @@ if {[info exists config::db(unconfigured)]} {
 	puts $fd "	[list set db(pass) $config::db(pass)]"
 	puts $fd "	[list set db(server) $config::db(server)]"
 	puts $fd "	[list set db(dbname) $config::db(dbname)]"
+	puts $fd "	[list unset db(unconfigured)]"
 	puts $fd "}"
 	close $fd
 }
 
 db::create -dbname sessions -fields [list sessionid data]
 db::create -dbname user -fields [list uid user name flags opts pass]
-db::create -dbname file -fields [list id name read write]
+db::create -dbname file -fields [list id name readperm writeperm]
 
 set manrootuid [uuid::gen user]
 db::set -dbname user -field uid $manrootuid -field user root -field flags [list root] -field pass "*LK*"
@@ -65,11 +69,11 @@ user::setuid $manrootuid
 set rootuid [user::create -user $rootuser -name "Administrator" -flags root -pass $rootpass]
 
 if {$rootuid == 0} {
-	set rootuid [getuid $rootuser]
+	set rootuid [user::getuid $rootuser]
 	user::change -uid $rootuid -flags root -pass $rootpass
 }
-user::delete $manrootuid
 user::setuid $rootuid
+user::delete $manrootuid
 
 set anonuid [user::create -user anonymous -name "Anonymous Web User"]
 if {$anonuid == 0} {
